FirestoreModelSettings class

Constructors

FirestoreModelSettings({bool? persistenceEnabled, String? host, bool? sslEnabled, int? cacheSizeBytes})
const

Properties

cacheSizeBytes → int?
final
hashCode → int
The hash code for this object.
no setterinherited
host → String?
The hostname to connect to.
final
persistenceEnabled → bool?
Attempts to enable persistent storage, if possible. This setting has no effect on Web, for Web use FirebaseFirestore.enablePersistence instead.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sslEnabled → bool?
Whether to use SSL when connecting.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

cacheSizeUnlimited → const int
Constant used to indicate the LRU garbage collection should be disabled.